
#
# Example: 
#	Perform an Extended Runs Test on Time Series Data
# 
# Description: 
#	This example shows how to perform an extended Runs Test using 
#	Fillibens runs test procedure.
#
# Author:
#	(C) 2002, Diethelm Wuertz, GPL
#


# ------------------------------------------------------------------------------


# Settings:

	data(nyseres)

# Runs Test:

	runsTest(nyseres[, 1])

	